@@ -1,8 +1,8 @@
 #' @title Generating Censored Autoregressive Dataset with Mixed Effects, for normal distribution.
-#' @import mvtnorm
+#' @import TruncatedNormal
+#' @import LaplacesDemon
 #' @import mnormt
 #' @import numDeriv
-#' @import tmvtnorm
 #' @import tcltk
 #' @import stats
 #' @import relliptical
@@ -17,8 +17,10 @@
 #' @param D Covariance Matrix for the random effects.
 #' @param phi Vector of length \code{Arp}, of values for autoregressive parameters. 
 #' @param struc  Correlation structure. This must be one of \code{UNC},\code{ARp},\code{DEC},\code{SYM} or \code{DEC(AR)}.
+#' @param order Order of the autoregressive process. Must be a positive integer value.
 #' @param typeModel \code{Normal} for Normal distribution and \code{Student} for t-Student distribution. Default is \code{Normal}
-#' @param p.cens Censoring level for the process. Default is \code{0}
+#' @param p.cens Censoring percentage for the process. Default is \code{NULL}
+#' @param n.cens Censoring level for the process. Default is \code{NULL}
 #' @param cens.type \code{left} for left censoring, \code{right} for right censoring and \code{interval} for intervalar censoring. Default is \code{left}
 #' @param nu degrees of freedom for t-Student distibution (nu > 0, maybe non-integer). 
 #' @return returns list:
@@ -36,16 +38,16 @@
 #'tt=rep(1:4,length(nj))
 #'x<-matrix(runif(sum(nj)*length(beta),-1,1),sum(nj),length(beta))
 #'z<-matrix(runif(sum(nj)*dim(D)[1],-1,1),sum(nj),dim(D)[1])
-#'data=ARpMMEC.sim(m,x,z,tt,nj,beta,sigma2,D,phi,struc="ARp",typeModel="Normal",p.cens)
+#'data=ARpMMEC.sim(m,x,z,tt,nj,beta,sigma2,D,phi,struc="ARp",typeModel="Normal",p.cens=p.cens)
 #'  y<-data$y_cc
 #'  cc<-data$cc
 #' }
 #' @export
-ARpMMEC.sim=function(m,x=NULL,z=NULL,tt=NULL,nj,beta,sigmae,D,phi,struc="ARp",typeModel="Normal",p.cens= 0,cens.type="left",nu=NULL)
+ARpMMEC.sim=function(m,x=NULL,z=NULL,tt=NULL,nj,beta,sigmae,D,phi,struc="ARp",order=1,typeModel="Normal",p.cens= NULL,n.cens= NULL,cens.type="left",nu=NULL)
 {
   
-   if(m==sum(nj))                        stop("not compatible sizes between m and nj")
-
+  if(m==sum(nj))                        stop("not compatible sizes between m and nj")
+  
   if(!is.null(x)){
     if(!is.numeric(x))                    stop("x must be a numeric matrix. Check documentation!")
     if(sum(is.na(x))>0)                   stop("There are some NA values in x.")
@@ -59,7 +61,7 @@ ARpMMEC.sim=function(m,x=NULL,z=NULL,tt=NULL,nj,beta,sigmae,D,phi,struc="ARp",ty
     
   }
   
-    if(!is.null(z)){
+  if(!is.null(z)){
     if(!is.numeric(z))                    stop("z must be a numeric matrix. Check documentation!")
     if(sum(is.na(z))>0)                   stop("There are some NA values in z.")
     if(!is.matrix(z))                     stop("z must be a matrix. Check documentation!")
@@ -67,31 +69,39 @@ ARpMMEC.sim=function(m,x=NULL,z=NULL,tt=NULL,nj,beta,sigmae,D,phi,struc="ARp",ty
     if(dim(z)[1]!=sum(nj))                stop("not compatible sizes between z and nj")
     if(dim(z)[2]!=dim(D)[2])             stop("not compatible sizes between z and D")
   }
- 
-   if(!is.numeric(nj))                   stop("nj must be a numeric vector. Check documentation!")
+  
+  if(!is.numeric(nj))                   stop("nj must be a numeric vector. Check documentation!")
   if(!is.vector(nj))                    stop("nj must be a vector. Check documentation!")
   if(sum(is.na(nj))>0)                  stop("There are some NA values in nj")
   if(length(nj)==0)                     stop("The parameter nj must be provided.")
   
-    if(!is.numeric(beta))             stop("beta must be a numeric vector. Check documentation!")
-    if(!is.vector(beta))              stop("beta must be a vector. Check documentation!")
-    if(!is.numeric(sigmae))           stop("sigmae must be a scalar.")
-    if(length(sigmae)>1)              stop("beta must be a scalar.")
-    if(!is.matrix(D))                stop("D must be a matrix.")
-    if(D[upper.tri(D)]!=D[lower.tri(D)])stop("D must be a simetric matrix.")
-    if(!is.numeric(phi))              stop("phi must be a numeric vector. Check documentation!")
-    if(sum(abs(phi))>=1)                   stop("the sum of the phi must be less than 1. Check documentation!")
-  
-    if(cens.type!="left" & cens.type!="right" & cens.type!="interval")stop('cens.type must be left, right or interval. Check documentation!')
+  if(!is.numeric(beta))             stop("beta must be a numeric vector. Check documentation!")
+  if(!is.vector(beta))              stop("beta must be a vector. Check documentation!")
+  if(!is.numeric(sigmae))           stop("sigmae must be a scalar.")
+  if(length(sigmae)>1)              stop("beta must be a scalar.")
+  if(!is.matrix(D))                stop("D must be a matrix.")
+  if(D[upper.tri(D)]!=D[lower.tri(D)])stop("D must be a simetric matrix.")
+  if(!is.numeric(phi))              stop("phi must be a numeric vector. Check documentation!")
+
+  if(cens.type!="left" & cens.type!="right" & cens.type!="interval")stop('cens.type must be left, right or interval. Check documentation!')
   if(typeModel!='Normal'& typeModel!='Student')   stop('typeModel must be Normal or Student. Check documentation!')
-
-  if(struc!="DEC"&struc!="DEC(AR)"&struc!="SYM"&struc!="ARp"&struc!="UNC") stop("Struc must be UNC, DEC, DEC(AR), SYM or ARp. Check documentation!")
-    if(p.cens>1| p.cens<0)       stop("the percCensu must be between 0 and 1 . Check documentation!")
-  if(!is.null(nu)){ 
-  if(!is.numeric(nu))                   stop("nu must be a numeric. Check documentation!")}
-  if(!is.numeric(p.cens))                   stop("p.cens must be a numeric. Check documentation!")
   
-  MMsimu(m=m,x=x,z=z,tt=tt,nj=nj,beta=beta,sigmae=sigmae,D=D,phi=phi,struc=struc,typeModel=typeModel,percCensu=p.cens,cens.type=cens.type,nu=nu)
-
-      }
+  if(struc!="DEC"&struc!="DEC(AR)"&struc!="SYM"&struc!="ARp"&struc!="UNC") stop("Struc must be UNC, DEC, DEC(AR), SYM or ARp. Check documentation!")
+  if(!is.null(p.cens)){
+  if(p.cens>1| p.cens<0)       stop("the p.cens must be between 0 and 1 . Check documentation!")
+  if(!is.numeric(p.cens))                   stop("p.cens must be a numeric. Check documentation!")
+  }
+  if(!is.null(n.cens)){
+    if(!is.null(p.cens))         stop("For the censoring only need the parameter n.cens or p.cents. Please, choose to specify n.cens or p.cens. Check documentation!")
+    if(!is.numeric(n.cens))                   stop("n.cens must be a numeric. Check documentation!")
+  }
+  if(!is.null(nu)){ 
+    if(!is.numeric(nu))                   stop("nu must be a numeric. Check documentation!")}
+  
+  if(struc=="ARp"){ 
+    if(length(phi)!=order)                   stop("not compatible information between phi and order. Check documentation!")}
+  
+  MMsimu(m=m,x=x,z=z,tt=tt,nj=nj,beta=beta,sigmae=sigmae,D=D,phi=phi,struc=struc,typeModel=typeModel,percCensu=p.cens,nivel.Censu=n.cens,cens.type=cens.type,nu=nu)
+  
+}
 
